// %flair:license{
// This file is part of the Flair framework distributed under the
// CECILL-C License, Version 1.0.
// %flair:license}
//  created:    2016/02/08
//  filename:   SimuX4.cpp
//
//  author:     Guillaume Sanahuja
//              Copyright Heudiasyc UMR UTC/CNRS 7253
//
//  version:    $Id: $
//
//  purpose:    Class defining a simulation x4 uav
//
//
/*********************************************************************/

#include "SimuX4.h"
#include <FrameworkManager.h>
#include <X4X8Multiplex.h>
#include <SimuImu.h>
#include <SimuAhrs.h>
#include <SimuBldc.h>
#include <SimuUs.h>
#include <SimuCamera.h>
#include <BatteryMonitor.h>
#include <Tab.h>

using std::string;
using namespace flair::core;
using namespace flair::gui;
using namespace flair::sensor;
using namespace flair::filter;
using namespace flair::actuator;

namespace flair {
namespace meta {

SimuX4::SimuX4(string name, int simu_id,
               filter::UavMultiplex *multiplex)
    : Uav(name, multiplex) {

  if (multiplex == NULL)
    SetMultiplex(new X4X8Multiplex(getFrameworkManager(), "motors", X4X8Multiplex::X4));

  SetBldc(new SimuBldc(GetUavMultiplex(), GetUavMultiplex()->GetLayout(),
                       "motors", GetUavMultiplex()->MotorsCount(), simu_id));
  SetUsRangeFinder(new SimuUs(getFrameworkManager(), "us", simu_id, 60));
  SetAhrs(new SimuAhrs(getFrameworkManager(), "imu", simu_id, 70));
  Tab *bat_tab = new Tab(getFrameworkManager()->GetTabWidget(), "battery");
  SetBatteryMonitor(new BatteryMonitor(bat_tab->NewRow(), "battery"));
  GetBatteryMonitor()->SetBatteryValue(12);
  SetVerticalCamera(
      new SimuCamera(getFrameworkManager(), "simu_cam_v", 320, 240, 3, simu_id, 10));
}

SimuX4::~SimuX4() {}

void SimuX4::StartSensors(void) {
  ((SimuAhrs *)GetAhrs())->Start();
  ((SimuUs *)GetUsRangeFinder())->Start();
  ((SimuCamera *)GetVerticalCamera())->Start();
}

} // end namespace meta
} // end namespace flair
